==> gd32f1-0.4.0.crate: gd32f1-0.4.0/src/gd32f190/tsi/g5cycn.rs <==
#[doc = "Register `G5CYCN` reader"]
pub struct R(crate::R<G5CYCN_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<G5CYCN_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<G5CYCN_SPEC>> for R {
    fn from(reader: crate::R<G5CYCN_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `CYCN` reader - Cycle number"]
pub struct CYCN_R(crate::FieldReader<u16, u16>);
impl CYCN_R {
    pub(crate) fn new(bits: u16) -> Self {
        CYCN_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CYCN_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:13 - Cycle number"]
    #[inline(always)]
    pub fn cycn(&self) -> CYCN_R {
        CYCN_R::new((self.bits & 0x3fff) as u16)
    }
}
#[doc = "I/O group x cycle number register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [g5cycn](index.html) module"]
pub struct G5CYCN_SPEC;
impl crate::RegisterSpec for G5CYCN_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [g5cycn::R](R) reader structure"]
impl crate::Readable for G5CYCN_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets G5CYCN to value 0"]
impl crate::Resettable for G5CYCN_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> gd32f1-0.5.0.crate: gd32f1-0.5.0/src/gd32f190/tsi/g5cycn.rs <==
#[doc = "Register `G5CYCN` reader"]
pub struct R(crate::R<G5CYCN_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<G5CYCN_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<G5CYCN_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<G5CYCN_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `CYCN` reader - Cycle number"]
pub struct CYCN_R(crate::FieldReader<u16, u16>);
impl CYCN_R {
    pub(crate) fn new(bits: u16) -> Self {
        CYCN_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CYCN_R {
    type Target = crate::FieldReader<u16, u16>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:13 - Cycle number"]
    #[inline(always)]
    pub fn cycn(&self) -> CYCN_R {
        CYCN_R::new((self.bits & 0x3fff) as u16)
    }
}
#[doc = "I/O group x cycle number register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [g5cycn](index.html) module"]
pub struct G5CYCN_SPEC;
impl crate::RegisterSpec for G5CYCN_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [g5cycn::R](R) reader structure"]
impl crate::Readable for G5CYCN_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets G5CYCN to value 0"]
impl crate::Resettable for G5CYCN_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
